@@ -12,7 +12,7 @@
 
 #define XTL_VERSION_MAJOR 0
 #define XTL_VERSION_MINOR 6
-#define XTL_VERSION_PATCH 16
+#define XTL_VERSION_PATCH 18
 
 #ifndef __has_feature
 #define __has_feature(x) 0
@@ -26,4 +26,14 @@
 #define XTL_NO_EXCEPTIONS
 #endif
 
+#if defined(XTL_NO_EXCEPTIONS)
+#define XTL_THROW(_, msg)              \
+    {                                  \
+        std::cerr << msg << std::endl; \
+        std::abort();                  \
+    }
+#else
+#define XTL_THROW(exception, msg) throw exception(msg)
+#endif
+
 #endif
